@@ -1,3 +1,4 @@
+import logging
 import sys
 from pkg_resources import iter_entry_points
 
@@ -9,9 +10,14 @@ from .config import (
     add_param_to_session
 )
 from .constants import PLUGIN_ENTRY_POINT
+from .exceptions import AudibleCliException
+from ._logging import click_basic_config, click_verbosity_option
 from . import __version__, plugins
 
 
+logger = logging.getLogger("audible_cli")
+click_basic_config(logger)
+
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
@@ -34,6 +40,7 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
     help="The password for the profile auth file."
 )
 @click.version_option(__version__)
+@click_verbosity_option(logger)
 def cli():
     """Entrypoint for all other subcommands and groups."""
 
@@ -41,16 +48,31 @@ def cli():
 @click.command(context_settings=CONTEXT_SETTINGS)
 @click.pass_context
 @click.version_option(__version__)
+@click_verbosity_option(logger)
 def quickstart(ctx):
     """Entrypoint for the quickstart command"""
     try:
         sys.exit(ctx.forward(cmd_quickstart.cli))
-    except KeyboardInterrupt:
-        sys.exit("\nERROR: Interrupted by user")
+    except click.Abort:
+        logger.error("Aborted")
+        sys.exit(1)
+    except AudibleCliException as e:
+        logger.error(e)
+        sys.exit(2)
+    except Exception:
+        logger.exception("Uncaught Exception")
+        sys.exit(3)
 
 
 def main(*args, **kwargs):
     try:
         sys.exit(cli(*args, **kwargs))
-    except KeyboardInterrupt:
-        sys.exit("\nERROR: Interrupted by user")
+    except click.Abort:
+        logger.error("Aborted")
+        sys.exit(1)
+    except AudibleCliException as e:
+        logger.error(e)
+        sys.exit(2)
+    except Exception:
+        logger.exception("Uncaught Exception")
+        sys.exit(3)
